==> localstack-ext-0.12.9.15.tar.gz: localstack-ext-0.12.9.15/localstack_ext/bootstrap/auth.py <==
import sys
cbygP=object
cbygN=staticmethod
cbygT=False
cbygl=Exception
cbyga=None
cbygz=input
cbygE=list
import json
import logging
import getpass
from localstack.config import CONFIG_FILE_PATH,load_config_file
from localstack.constants import API_ENDPOINT
from localstack.utils.common import to_str,safe_requests,save_file,load_file
LOG=logging.getLogger(__name__)
class AuthProvider(cbygP):
 @cbygN
 def name():
  raise
 def get_or_create_token(self,username,password,headers):
  pass
 def get_user_for_token(self,token):
  pass
 @cbygN
 def providers():
  return{c.name():c for c in AuthProvider.__subclasses__()}
 @cbygN
 def get(provider,raise_error=cbygT):
  provider_class=AuthProvider.providers().get(provider)
  if not provider_class:
   msg='Unable to find auth provider class "%s"'%provider
   LOG.warning(msg)
   if raise_error:
    raise cbygl(msg)
   return cbyga
  return provider_class()
class AuthProviderInternal(AuthProvider):
 @cbygN
 def name():
  return 'internal'
 def get_or_create_token(self,username,password,headers):
  data={'username':username,'password':password}
  response=safe_requests.post('%s/user/signin'%API_ENDPOINT,json.dumps(data),headers=headers)
  if response.status_code>=400:
   return
  try:
   result=json.loads(to_str(response.content or '{}'))
   return result['token']
  except cbygl:
   pass
 def read_credentials(self,username):
  print('Please provide your login credentials below')
  if not username:
   sys.stdout.write('Username: ')
   sys.stdout.flush()
   username=cbygz()
  password=getpass.getpass()
  return username,password,{}
 def get_user_for_token(self,token):
  raise cbygl('Not implemented')
def login(provider,username=cbyga):
 auth_provider=AuthProvider.get(provider)
 if not auth_provider:
  providers=cbygE(AuthProvider.providers().keys())
  raise cbygl('Unknown provider "%s", should be one of %s'%(provider,providers))
 username,password,headers=auth_provider.read_credentials(username)
 print('Verifying credentials ... (this may take a few moments)')
 token=auth_provider.get_or_create_token(username,password,headers)
 if not token:
  raise cbygl('Unable to verify login credentials - please try again')
 configs=load_config_file()
 configs['login']={'provider':provider,'username':username,'token':token}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def logout():
 configs=json_loads(load_file(CONFIG_FILE_PATH,default='{}'))
 configs['login']={}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def json_loads(s):
 return json.loads(to_str(s))
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.12.9.16.tar.gz: localstack-ext-0.12.9.16/localstack_ext/bootstrap/auth.py <==
import sys
sYBXe=object
sYBXa=staticmethod
sYBXQ=False
sYBXI=Exception
sYBXP=None
sYBXL=input
sYBXb=list
import json
import logging
import getpass
from localstack.config import CONFIG_FILE_PATH,load_config_file
from localstack.constants import API_ENDPOINT
from localstack.utils.common import to_str,safe_requests,save_file,load_file
LOG=logging.getLogger(__name__)
class AuthProvider(sYBXe):
 @sYBXa
 def name():
  raise
 def get_or_create_token(self,username,password,headers):
  pass
 def get_user_for_token(self,token):
  pass
 @sYBXa
 def providers():
  return{c.name():c for c in AuthProvider.__subclasses__()}
 @sYBXa
 def get(provider,raise_error=sYBXQ):
  provider_class=AuthProvider.providers().get(provider)
  if not provider_class:
   msg='Unable to find auth provider class "%s"'%provider
   LOG.warning(msg)
   if raise_error:
    raise sYBXI(msg)
   return sYBXP
  return provider_class()
class AuthProviderInternal(AuthProvider):
 @sYBXa
 def name():
  return 'internal'
 def get_or_create_token(self,username,password,headers):
  data={'username':username,'password':password}
  response=safe_requests.post('%s/user/signin'%API_ENDPOINT,json.dumps(data),headers=headers)
  if response.status_code>=400:
   return
  try:
   result=json.loads(to_str(response.content or '{}'))
   return result['token']
  except sYBXI:
   pass
 def read_credentials(self,username):
  print('Please provide your login credentials below')
  if not username:
   sys.stdout.write('Username: ')
   sys.stdout.flush()
   username=sYBXL()
  password=getpass.getpass()
  return username,password,{}
 def get_user_for_token(self,token):
  raise sYBXI('Not implemented')
def login(provider,username=sYBXP):
 auth_provider=AuthProvider.get(provider)
 if not auth_provider:
  providers=sYBXb(AuthProvider.providers().keys())
  raise sYBXI('Unknown provider "%s", should be one of %s'%(provider,providers))
 username,password,headers=auth_provider.read_credentials(username)
 print('Verifying credentials ... (this may take a few moments)')
 token=auth_provider.get_or_create_token(username,password,headers)
 if not token:
  raise sYBXI('Unable to verify login credentials - please try again')
 configs=load_config_file()
 configs['login']={'provider':provider,'username':username,'token':token}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def logout():
 configs=json_loads(load_file(CONFIG_FILE_PATH,default='{}'))
 configs['login']={}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def json_loads(s):
 return json.loads(to_str(s))
# Created by pyminifier (https://github.com/liftoff/pyminifier)
